==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/security/kotlin/inputs/DenylistCustomAlertRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.security.kotlin.inputs

import com.pulumi.azurenative.security.inputs.DenylistCustomAlertRuleArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * A custom alert rule that checks if a value (depends on the custom alert type) is denied.
 * @property denylistValues The values to deny. The format of the values depends on the rule type.
 * @property isEnabled Status of the custom alert.
 * @property ruleType The type of the custom alert rule.
 * Expected value is 'DenylistCustomAlertRule'.
 */
public data class DenylistCustomAlertRuleArgs(
    public val denylistValues: Output<List<String>>,
    public val isEnabled: Output<Boolean>,
    public val ruleType: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.security.inputs.DenylistCustomAlertRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.security.inputs.DenylistCustomAlertRuleArgs =
        com.pulumi.azurenative.security.inputs.DenylistCustomAlertRuleArgs.builder()
            .denylistValues(denylistValues.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .isEnabled(isEnabled.applyValue({ args0 -> args0 }))
            .ruleType(ruleType.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DenylistCustomAlertRuleArgs].
 */
@PulumiTagMarker
public class DenylistCustomAlertRuleArgsBuilder internal constructor() {
    private var denylistValues: Output<List<String>>? = null

    private var isEnabled: Output<Boolean>? = null

    private var ruleType: Output<String>? = null

    /**
     * @param value The values to deny. The format of the values depends on the rule type.
     */
    @JvmName("ewdvtjqopbwbbdwh")
    public suspend fun denylistValues(`value`: Output<List<String>>) {
        this.denylistValues = value
    }

    @JvmName("cctlbqamjwdscjqq")
    public suspend fun denylistValues(vararg values: Output<String>) {
        this.denylistValues = Output.all(values.asList())
    }

    /**
     * @param values The values to deny. The format of the values depends on the rule type.
     */
    @JvmName("akkpquurbaelifyy")
    public suspend fun denylistValues(values: List<Output<String>>) {
        this.denylistValues = Output.all(values)
    }

    /**
     * @param value Status of the custom alert.
     */
    @JvmName("efvvxftvtffvrbcj")
    public suspend fun isEnabled(`value`: Output<Boolean>) {
        this.isEnabled = value
    }

    /**
     * @param value The type of the custom alert rule.
     * Expected value is 'DenylistCustomAlertRule'.
     */
    @JvmName("pkxfcdcjgtkhcxsr")
    public suspend fun ruleType(`value`: Output<String>) {
        this.ruleType = value
    }

    /**
     * @param value The values to deny. The format of the values depends on the rule type.
     */
    @JvmName("fwiedrenfwwitafk")
    public suspend fun denylistValues(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.denylistValues = mapped
    }

    /**
     * @param values The values to deny. The format of the values depends on the rule type.
     */
    @JvmName("ipsqmideospgwmxs")
    public suspend fun denylistValues(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.denylistValues = mapped
    }

    /**
     * @param value Status of the custom alert.
     */
    @JvmName("shxdfurgsbamcvgd")
    public suspend fun isEnabled(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.isEnabled = mapped
    }

    /**
     * @param value The type of the custom alert rule.
     * Expected value is 'DenylistCustomAlertRule'.
     */
    @JvmName("ulohjirukpvyeaew")
    public suspend fun ruleType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleType = mapped
    }

    internal fun build(): DenylistCustomAlertRuleArgs = DenylistCustomAlertRuleArgs(
        denylistValues = denylistValues ?: throw PulumiNullFieldException("denylistValues"),
        isEnabled = isEnabled ?: throw PulumiNullFieldException("isEnabled"),
        ruleType = ruleType ?: throw PulumiNullFieldException("ruleType"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/security/kotlin/inputs/DenylistCustomAlertRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.security.kotlin.inputs

import com.pulumi.azurenative.security.inputs.DenylistCustomAlertRuleArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * A custom alert rule that checks if a value (depends on the custom alert type) is denied.
 * @property denylistValues The values to deny. The format of the values depends on the rule type.
 * @property isEnabled Status of the custom alert.
 * @property ruleType The type of the custom alert rule.
 * Expected value is 'DenylistCustomAlertRule'.
 */
public data class DenylistCustomAlertRuleArgs(
    public val denylistValues: Output<List<String>>,
    public val isEnabled: Output<Boolean>,
    public val ruleType: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.security.inputs.DenylistCustomAlertRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.security.inputs.DenylistCustomAlertRuleArgs =
        com.pulumi.azurenative.security.inputs.DenylistCustomAlertRuleArgs.builder()
            .denylistValues(denylistValues.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .isEnabled(isEnabled.applyValue({ args0 -> args0 }))
            .ruleType(ruleType.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DenylistCustomAlertRuleArgs].
 */
@PulumiTagMarker
public class DenylistCustomAlertRuleArgsBuilder internal constructor() {
    private var denylistValues: Output<List<String>>? = null

    private var isEnabled: Output<Boolean>? = null

    private var ruleType: Output<String>? = null

    /**
     * @param value The values to deny. The format of the values depends on the rule type.
     */
    @JvmName("dwyyfyxygamiidrt")
    public suspend fun denylistValues(`value`: Output<List<String>>) {
        this.denylistValues = value
    }

    @JvmName("fwtswcrsinkpapny")
    public suspend fun denylistValues(vararg values: Output<String>) {
        this.denylistValues = Output.all(values.asList())
    }

    /**
     * @param values The values to deny. The format of the values depends on the rule type.
     */
    @JvmName("wkxsvpohoqgkjmjs")
    public suspend fun denylistValues(values: List<Output<String>>) {
        this.denylistValues = Output.all(values)
    }

    /**
     * @param value Status of the custom alert.
     */
    @JvmName("atmhsijhiasvxtyj")
    public suspend fun isEnabled(`value`: Output<Boolean>) {
        this.isEnabled = value
    }

    /**
     * @param value The type of the custom alert rule.
     * Expected value is 'DenylistCustomAlertRule'.
     */
    @JvmName("bdgdcykesosyqyop")
    public suspend fun ruleType(`value`: Output<String>) {
        this.ruleType = value
    }

    /**
     * @param value The values to deny. The format of the values depends on the rule type.
     */
    @JvmName("sbwhpedkfrrkdjvg")
    public suspend fun denylistValues(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.denylistValues = mapped
    }

    /**
     * @param values The values to deny. The format of the values depends on the rule type.
     */
    @JvmName("umcqcmnrdkywjebb")
    public suspend fun denylistValues(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.denylistValues = mapped
    }

    /**
     * @param value Status of the custom alert.
     */
    @JvmName("jcgsoxvrdcnewprw")
    public suspend fun isEnabled(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.isEnabled = mapped
    }

    /**
     * @param value The type of the custom alert rule.
     * Expected value is 'DenylistCustomAlertRule'.
     */
    @JvmName("tsxasoxxlefsmeho")
    public suspend fun ruleType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleType = mapped
    }

    internal fun build(): DenylistCustomAlertRuleArgs = DenylistCustomAlertRuleArgs(
        denylistValues = denylistValues ?: throw PulumiNullFieldException("denylistValues"),
        isEnabled = isEnabled ?: throw PulumiNullFieldException("isEnabled"),
        ruleType = ruleType ?: throw PulumiNullFieldException("ruleType"),
    )
}
